.. image:: https://img.shields.io/pypi/v/yason.svg
        :target: https://pypi.python.org/pypi/yason

.. image:: https://img.shields.io/travis/com/ktaletsk/yason.svg
        :target: https://travis-ci.com/ktaletsk/yason

.. image:: https://readthedocs.org/projects/yason/badge/?version=latest
        :target: https://yason.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/ktaletsk/yason/shield.svg
     :target: https://pyup.io/repos/github/ktaletsk/yason/
     :alt: Updates

==========================================
yason: Jupyter Notebook Scheduler for Argo
==========================================

.. image:: logo.png
    :height: 50px
    :align: center
    :alt: logo



Python package and CLI to schedule Jupyter Notebook execution with Papermill on Argo cluster


* Free software: MIT license
* Documentation: https://yason.readthedocs.io.


Features
--------

* Check the status of all scheduled notebook jobs
* Schedule a notebook for execution
* Get resulting notebook after execution
* Delete scheduled notebook job

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
